@@ -5,7 +5,7 @@
 #include <string.h>
 #include "btparse.h"
 
-void main (void)
+int main (void)
 {
    char   line[1024];
    int    line_num;
@@ -38,4 +38,5 @@ void main (void)
          }
       }
    }
+   return 0;
 }
